==> binypt_lib-2.0.0.tar.gz: binypt_lib-2.0.0/DOCUMENTATION.md <==
## Binypt Library User Documentation

Welcome to the user documentation for the **Binypt** library. This library is designed to assist you in fetching cryptocurrency price data from Binance with ease. This document will guide you through the library's functionality and provide step-by-step instructions on how to use it effectively.

### Table of Contents

- [Binypt Library User Documentation](#binypt-library-user-documentation)
  - [Table of Contents](#table-of-contents)
  - [1. Installation](#1-installation)
  - [2. Getting Started](#2-getting-started)
  - [3. Setting Up Binypt](#3-setting-up-binypt)
    - [3.1. Initializing Binypt](#31-initializing-binypt)
    - [3.2. Setting Data Retrieval Parameters](#32-setting-data-retrieval-parameters)
  - [4. Fetching Cryptocurrency Price Data](#4-fetching-cryptocurrency-price-data)
  - [5. Exporting Data](#5-exporting-data)
  - [6. Adding Human-Readable Timestamps](#6-adding-human-readable-timestamps)
  - [7. Setting Verbosity Options](#7-setting-verbosity-options)
  - [8. Complete Example](#8-complete-example)
  - [9. Conclusion](#9-conclusion)

### 1. Installation

Before using the **Binypt** library, you need to install it. You can do this using `pip`:

```bash
pip install binypt-lib
```

### 2. Getting Started

To get started with **Binypt**, make sure you have Python installed on your system. You can use Python 3.10 or later.

### 3. Setting Up Binypt

#### 3.1. Initializing Binypt

The first step is to create a `Binypt` object, which will serve as your interface to the library.

```python
from binypt import Binypt
binypt = Binypt()
```

#### 3.2. Setting Data Retrieval Parameters

Before fetching cryptocurrency price data, you need to specify the trading pair, interval, start date, and end date. Use the `set_arguments` method for this purpose.

```python
binypt.set_arguments("BTCUSDT", "1h", "01/09/2023-00:00:00", "10/09/2023-23:59:59")
```

- `trading_pair` (str): Cryptocurrency pair, e.g., "BTCUSDT".
- `interval` (str): Time interval, e.g., "1h" for 1-hour data.
- `open_date` (str): Start date in the format "dd/mm/yyyy-HH:MM:SS".
- `close_date` (str): End date in the format "dd/mm/yyyy-HH:MM:SS".

### 4. Fetching Cryptocurrency Price Data

Once you have set up the data retrieval parameters, you can fetch cryptocurrency price data from Binance using the `retrieve_data` method:

```python
binypt.retrieve_data()
```

> Binypt library automatically caches downloaded data to `.data_cache.pkl` while fetching upcoming batches. In case of an error, use `pandas.read_pickle()` function to read the partially downloaded data. 

### 5. Exporting Data

You can export the downloaded data to a file with the `export` method. Specify the absolute file path with the desired file format (CSV, Excel, or Pickle):

```python
binypt.export("crypto_data.csv")
```

### 6. Adding Human-Readable Timestamps

To make the timestamps in the data more human-readable, you can use the `add_human_readable_time` method:

```python
binypt.add_human_readable_time()
```

This method converts Unix timestamps to human-readable datetime objects.

### 7. Setting Verbosity Options

You can control the verbosity of the library using the `set_verbosity` method. By default, neither the progress bar nor log messages are displayed. To enable them, use this method:

```python
binypt.set_verbosity(show_bar=True, show_log=True)
```

- `show_bar` (bool, optional): Show a progress bar (default is `False`).
- `show_log` (bool, optional): Show log messages (default is `False`).

### 8. Complete Example

Here's a complete example that demonstrates the entire process, from initialization to data export:

```python
from binypt import Binypt

# Initialize Binypt
binypt = Binypt()

# Set data retrieval parameters
binypt.set_arguments("BTCUSDT", "1h", "01/09/2023-00:00:00", "10/09/2023-23:59:59")

# Fetch cryptocurrency price data
binypt.retrieve_data()

# Export data to a CSV file
binypt.export("crypto_data.csv")

# Add human-readable timestamps
binypt.add_human_readable_time()

# Show progress bar and log messages
binypt.set_verbosity(show_bar=True, show_log=True)

# Access the data as a Pandas DataFrame
price_data = binypt.get_data()

# You can now perform various data analysis or visualization tasks with the price_data DataFrame
```

### 9. Conclusion

You have now learned how to use the **Binypt** library to fetch cryptocurrency price data from Binance, export it to a file, and enhance it with human-readable timestamps. Explore the library further to analyze and visualize cryptocurrency data for your trading and research needs.

---

*Generated by GPT*

==> binypt_lib-2.3.6a1.tar.gz: binypt_lib-2.3.6a1/DOCUMENTATION.md <==
## Binypt Library User Documentation

Welcome to the user documentation for the **Binypt** library. This library is designed to assist you in fetching cryptocurrency price data from Binance with ease. This document will guide you through the library's functionality and provide step-by-step instructions on how to use it effectively.

### Table of Contents

- [Binypt Library User Documentation](#binypt-library-user-documentation)
  - [Table of Contents](#table-of-contents)
  - [1. Installation](#1-installation)
  - [2. Getting Started](#2-getting-started)
  - [3. Setting Up Binypt](#3-setting-up-binypt)
    - [3.1. Initializing Binypt](#31-initializing-binypt)
    - [3.2. Setting Data Retrieval Parameters](#32-setting-data-retrieval-parameters)
  - [4. Fetching Cryptocurrency Price Data](#4-fetching-cryptocurrency-price-data)
  - [5. Exporting Data](#5-exporting-data)
  - [6. Adding Human-Readable Timestamps](#6-adding-human-readable-timestamps)
  - [7. Setting Verbosity Options](#7-setting-verbosity-options)
  - [8. Complete Example](#8-complete-example)
  - [9. Conclusion](#9-conclusion)

### 1. Installation

Before using the **Binypt** library, you need to install it. You can do this using `pip`:

```bash
pip install binypt-lib
```

### 2. Getting Started

To get started with **Binypt**, make sure you have Python installed on your system. You can use Python 3.10 or later.

### 3. Setting Up Binypt

#### 3.1. Initializing Binypt

The first step is to create a `Binypt` object, which will serve as your interface to the library.

```python
from binypt import Binypt
binypt = Binypt()
```

#### 3.2. Setting Data Retrieval Parameters

Before fetching cryptocurrency price data, you need to specify the trading pair, interval, start date, and end date. Use the `set_arguments` method for this purpose.

```python
binypt.set_arguments("BTCUSDT", "1h", "01/09/2023-00:00:00", "10/09/2023-23:59:59")
```

- `trading_pair` (str): Cryptocurrency pair, e.g., "BTCUSDT".
- `interval` (str): Time interval, e.g., "1h" for 1-hour data.
- `open_date` (str): Start date in the format "dd/mm/yyyy-HH:MM:SS".
- `close_date` (str): End date in the format "dd/mm/yyyy-HH:MM:SS".

### 4. Fetching Cryptocurrency Price Data

Once you have set up the data retrieval parameters, you can fetch cryptocurrency price data from Binance using the `retrieve_data` method:

```python
binypt.retrieve_data()
```

> Binypt library automatically caches downloaded data to `.data_cache.pickle` while fetching upcoming batches. In case of an error, use `pandas.read_pickle()` function to read the partially downloaded data. 

### 5. Exporting Data

You can export the downloaded data to a file with the `export` method. Specify the absolute file path with the desired file format (CSV, Excel, or Pickle):

```python
binypt.export("crypto_data.csv")
```

### 6. Adding Human-Readable Timestamps

To make the timestamps in the data more human-readable, you can use the `add_human_readable_time` method:

```python
binypt.add_human_readable_time()
```

This method converts Unix timestamps to human-readable datetime objects.

### 7. Setting Verbosity Options

You can control the verbosity of the library using the `set_verbosity` method. By default, neither the progress bar nor log messages are displayed. To enable them, use this method:

```python
binypt.set_verbosity(show_bar=True, show_log=True)
```

- `show_bar` (bool, optional): Show a progress bar (default is `False`).
- `show_log` (bool, optional): Show log messages (default is `False`).

### 8. Complete Example

Here's a complete example that demonstrates the entire process, from initialization to data export:

```python
from binypt import Binypt

# Initialize Binypt
binypt = Binypt()

# Set data retrieval parameters
binypt.set_arguments("BTCUSDT", "1h", "01/09/2023-00:00:00", "10/09/2023-23:59:59")

# Fetch cryptocurrency price data
binypt.retrieve_data()

# Export data to a CSV file
binypt.export("crypto_data.csv")

# Add human-readable timestamps
binypt.add_human_readable_time()

# Show progress bar and log messages
binypt.set_verbosity(show_bar=True, show_log=True)

# Access the data as a Pandas DataFrame
price_data = binypt.get_data()

# You can now perform various data analysis or visualization tasks with the price_data DataFrame
```

### 9. Conclusion

You have now learned how to use the **Binypt** library to fetch cryptocurrency price data from Binance, export it to a file, and enhance it with human-readable timestamps. Explore the library further to analyze and visualize cryptocurrency data for your trading and research needs.

---

[![Generated by ChatGPT](https://img.shields.io/badge/Generated%20by-ChatGPT-45b39d.svg)](https://chat.openai.com/)
